// Copyright (c) 2002, Peter Bentley
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//   Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
//   Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
//   The name Peter Bentley may not be used to endorse or promote
// products derived from this software without specific prior
// written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// $Id: PreferenceController.h,v 1.3 2003/04/17 19:27:32 pete Exp $

#import <AppKit/AppKit.h>
#import "omd.h"

extern NSString *OmdDebugLevelKey;
extern NSString *OmdShowDebugKey;
extern NSString *OmdActionIfNoUnitKey;
extern NSString *OmdSlowTickKey;
extern NSString *OmdFastTickKey;
extern NSString *OmdStatusClearKey;


extern NSString *OmdPrefsChangedNotification;

#define OMD_ACTION_EXIT		0
#define OMD_ACTION_IGNORE	1
#define OMD_ACTION_PROBEALL	2
#define OMD_ACTION_PROMPT	3


@interface PreferenceController : NSWindowController {
    // UI elements
    IBOutlet NSPopUpButton	*debugPopup;
    IBOutlet NSButton		*showDebugSwitch;
    IBOutlet NSMatrix		*startActionMatrix;
    IBOutlet NSSlider		*slowTickSlider;
    IBOutlet NSSlider		*fastTickSlider;
        
    // Standard user defaults
    NSUserDefaults		*defaults;
}

- (IBAction) okPressed: (id) sender;
- (IBAction) debugChanged: (id) sender;
- (IBAction) showDebugChanged: (id) sender;
- (IBAction) startActionChanged: (id) sender;
- (IBAction) slowTickChanged: (id) sender;
- (IBAction) fastTickChanged: (id) sender;


- (void) updateView;

- (void) doNotify: (NSString *) key;
@end
