// Copyright (c) 2002, Peter Bentley
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//   Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
//   Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
//   The name Peter Bentley may not be used to endorse or promote
// products derived from this software without specific prior
// written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//



#import "PreferenceController.h"

CVSID( "$Id: PreferenceController.m,v 1.3 2003/04/17 19:29:09 pete Exp $" );

NSString *OmdDebugLevelKey = @"DebugLevel";
NSString *OmdShowDebugKey = @"ShowDebug";
NSString *OmdActionIfNoUnitKey = @"NoUnitAction";
NSString *OmdSlowTickKey = @"SlowTick";
NSString *OmdFastTickKey = @"FastTick";
NSString *OmdStatusClearKey = @"StatusClear";


NSString *OmdPrefsChangedNotification = @"OMD Preferences Changed";

@implementation PreferenceController

- (id) init
{
    self = [super initWithWindowNibName: @"Preferences"];
    if( self )
    {
        defaults = [NSUserDefaults standardUserDefaults];
    }
    return self;
}

- (void) dealloc
{
    [defaults synchronize];
    [defaults release];
    [super dealloc];
}

- (void) windowDidLoad
{
    NSLog( @"Prefs nib loaded" );
    
    [self updateView];
}

- (IBAction) okPressed: (id) sender
{
    slog( LOG_INFO, "OK!" );
    [defaults synchronize];
    [[self window] performClose: self];
}

- (IBAction) debugChanged: (id) sender
{
    
    [defaults setInteger: [sender indexOfSelectedItem] forKey: OmdDebugLevelKey];
    [self doNotify: OmdDebugLevelKey];
}

- (IBAction) showDebugChanged: (id) sender
{
    
    [defaults setBool: [sender intValue] forKey: OmdShowDebugKey];
    [self doNotify: OmdDebugLevelKey];
}

- (IBAction) startActionChanged: (id) sender
{
    slog( LOG_TRACE, "New start action: %d", [[sender selectedCell] tag] );
    [defaults setInteger: [[sender selectedCell] tag] forKey: OmdActionIfNoUnitKey];
    [self doNotify: OmdActionIfNoUnitKey];
}

- (IBAction) slowTickChanged: (id) sender
{
    slog( LOG_TRACE, "Slow tick: %g", [sender floatValue] );
    [defaults setFloat: [sender floatValue] forKey: OmdSlowTickKey];
    [self doNotify: OmdSlowTickKey];
}

- (IBAction) fastTickChanged: (id) sender
{
    slog( LOG_TRACE, "Fast tick: %g", [sender floatValue] );
    [defaults setFloat: [sender floatValue] forKey: OmdFastTickKey];
    [self doNotify: OmdFastTickKey];
}




- (void) updateView
{
    int dbglvl = [defaults integerForKey: OmdDebugLevelKey];

    // slog( LOG_INFO, "Current debug level: %d", dbglvl );
    [debugPopup selectItemAtIndex: dbglvl];
    [startActionMatrix selectCellWithTag: [defaults integerForKey: OmdActionIfNoUnitKey]];
    [showDebugSwitch setIntValue: [defaults boolForKey: OmdShowDebugKey]];
    [slowTickSlider setFloatValue: [defaults floatForKey: OmdSlowTickKey]];
    [fastTickSlider setFloatValue: [defaults floatForKey: OmdFastTickKey]];
}

- (void) doNotify: (NSString *) key
{
    [[NSNotificationCenter defaultCenter] postNotificationName: 			OmdPrefsChangedNotification object: key];
}

@end
