#!/bin/sh

die () {
    echo "*** $@"
    echo "*** Build failed"
    exit 1
}

test -d "Xmd.pbproj" || die "OS X build script being run in wrong directory"

DATAG=`date +%d-%b-%Y`
VOLNAME="Xmd CVS build on $DATAG"
APPNAME="Xmd-$DATAG.app"
TMPIMGNAME="Xmd-tmp.dmg"
FINIMGNAME="Xmd-$DATAG.dmg"
DESTDIR=/Volumes/radix.sorted.org/public_html/Xmd/cvsbuild
echo "Tag: $DATAG, Vol: $VOLNAME, App: $APPNAME"

echo "Compiling..."
pbxbuild -buildstyle Deployment clean build > /dev/null || die "Compile failed"

cd build || die "Unable to cd to build directory"

test -f "$TMPIMGNAME" && rm -f "$TMPIMGNAME" 
test -f "$FINIMGNAME" && rm -f "$FINIMGNAME" 

echo "Creating temporary disk image"
hdiutil create -quiet -size 5m -fs HFS+ -volname "$VOLNAME" $TMPIMGNAME || die "Unable to create image"

hdiutil attach -quiet $TMPIMGNAME || die "Unable to attach temp image"

echo "Copying..."
ditto -rsrcFork Xmd.app "/Volumes/$VOLNAME/$APPNAME" || die "ditto failed"

echo "Unmounting..."
VOLDEV=`mount | grep "/Volumes/$VOLNAME" | awk '{print $1}'`
test "$VOLDEV" || die "Unable to locate new volume"

hdiutil detach -quiet $VOLDEV

echo "Converting..."
hdiutil convert -quiet -format UDZO -o "$FINIMGNAME" $TMPIMGNAME || die "Convert failed"
rm -f $TMPIMGNAME || die "Unable to delete temporary image"

echo "Copying to $DESTDIR"
cp "$FINIMGNAME" $DESTDIR || die "Copy failed"
#chmod 644 "$DESTDIR/$FINIMGNAME" | die "chmod failed"

echo "Done!"

